@@ -168,14 +168,14 @@ def testing_server(raw_testing_server, monkeypatch):
 
     # Teardown verification, in case that the server logged an
     # error that wasn't notified to the client or we just made a mistake.
-    for c in raw_testing_server.error_log.calls:
-        if c.level <= logging.WARNING:
+    for c_msg, c_level, c_traceback in raw_testing_server.error_log.calls:
+        if c_level <= logging.WARNING:
             continue
 
-        assert c.msg in raw_testing_server.error_log.ignored_msgs, (
+        assert c_msg in raw_testing_server.error_log.ignored_msgs, (
             'Found error in the error log: '
-            "message = '{c.msg}', level = '{c.level}'\n"
-            '{c.traceback}'.format(**locals()),
+            "message = '{c_msg}', level = '{c_level}'\n"
+            '{c_traceback}'.format(**locals()),
         )
 
 
@@ -1009,9 +1009,12 @@ def test_Content_Length_out(
     # the server logs the exception that we had verified from the
     # client perspective. Tell the error_log verification that
     # it can ignore that message.
-    test_client.server_instance.error_log.ignored_msgs.append(
+    test_client.server_instance.error_log.ignored_msgs.extend((
+        # Python 3.7+:
         "ValueError('Response body exceeds the declared Content-Length.')",
-    )
+        # Python 2.7-3.6 (macOS?):
+        "ValueError('Response body exceeds the declared Content-Length.',)",
+    ))
 
 
 @pytest.mark.xfail(
@@ -1094,7 +1097,7 @@ class FaultyGetMap:
     def __call__(self):
         """Intercept the calls to selector.get_map."""
         sabotage_targets = (
-            conn for _, (*_, conn) in self.original_get_map().items()
+            conn for _, (_, _, _, conn) in self.original_get_map().items()
             if isinstance(conn, cheroot.server.HTTPConnection)
         ) if self.sabotage_conn else ()
 
@@ -1147,3 +1150,8 @@ def test_invalid_selected_connection(test_client, monkeypatch):
     assert faux_get_map.socket_closed
     # any error in the error handling should be catched by the
     # teardown verification for the error_log
+
+    if six.PY2:
+        test_client.server_instance.error_log.ignored_msgs.append(
+            'Error in HTTPServer.tick',
+        )
